@@ -1,7 +1,8 @@
 #!/bin/bash
 VERSION='0.6'
 #
-# Copyright (C) 2003-2008  Ola Lundqvist <opal@debian.org>
+# Copyright (C) 2003-2009  Ola Lundqvist <opal@debian.org>
+# Copyright (C) 2009       Stefan Tomanek <stefan@pico.ruhr.de>
 # Copyright (C) 2007       Tijs van Dam <tijsvd@bluescraper.com>
 # Copyright (C) 2007       Jochen Voss <voss@seehuhn.de>
 # Copyright (C) 2006       Miroslav Kure <kurem@upcase.inf.upol.cz>
@@ -553,8 +554,8 @@ iface lo inet loopback
 EOF
 
 # grab DNS servers from the host-server for `resolv.conf'
-HOST_IP=$(ip -o addr show dev $INTERFACE primary scope global | \
-          sed -n 's;.*inet \([^/]*\)/.*;\1;p'  | head -1)
+HOST_IP=$(ip -4 -o addr show primary scope global dev "$INTERFACE" | \
+          awk '$3 == "inet" {split($4,i,"/"); print i[1]; exit}')
 (echo search $VDOMAIN;
  grep '^nameserver' /etc/resolv.conf | sed "s/127.0.0.1/$HOST_IP/") \
     > "$VROOTDIR/$VHOST/etc/resolv.conf"
