@@ -1,7 +1,8 @@
 #!/bin/bash
 VERSION='0.6'
 #
-# Copyright (C) 2002-2008  Ola Lundqvist <opal@debian.org>
+# Copyright (C) 2002-2009  Ola Lundqvist <opal@debian.org>
+# Copyright (C) 2009       Stefan Tomanek <stefan@pico.ruhr.de>
 # Copyright (C) 2008       Vincent Bernat <bernat@luffy.cx>
 # Copyright (C) 2007       Tijs van Dam <tijsvd@bluescraper.com>
 # Copyright (C) 2007       Jochen Voss <voss@seehuhn.de>
@@ -559,8 +560,8 @@ ff02::3 ip6-allhosts
 EOF
 
 # grab DNS servers from the host-server for `resolv.conf'
-HOST_IP=$(ip -o addr show dev $INTERFACE primary scope global | \
-          sed -n 's;.*inet \([^/]*\)/.*;\1;p' | head -1)
+HOST_IP=$(ip -4 -o addr show primary scope global dev "$INTERFACE" | \
+          awk '$3 == "inet" {split($4,i,"/"); print i[1]; exit}')
 (echo search $VDOMAIN;
  grep '^nameserver' /etc/resolv.conf | sed "s/127.0.0.1/$HOST_IP/") \
     > "$VROOTDIR/$VHOST/etc/resolv.conf"
